@@ -879,10 +879,12 @@ def get_texture_efficiency(model):
         efficiencies.append(utilization)
         print(f'Texture {i}: {utilization:.0%}')
 
+    efficiency = (total_pixels_used / total_pixels) if total_pixels else 1
+
     return {
         'efficiencies': efficiencies,
         'total_pixels': total_pixels,
         'total_pixels_used': total_pixels_used,
-        'overall_efficiency': total_pixels_used / total_pixels,
-        'overall_inefficiency': 1 - (total_pixels_used / total_pixels),
+        'overall_efficiency': efficiency,
+        'overall_inefficiency': 1 - efficiency,
     }
